System.register([], (function (exports) {
	'use strict';
	return {
		execute: (function () {

			const value = exports('value', 'included');

		})
	};
}));
